@@ -27,8 +27,7 @@ align = {
 
 btn = {
     'checked': ['setChecked', [int, bool]],
-    'checkable': ['setCheckable', bool],
-    'enabled': ['setEnabled', bool]
+    'checkable': ['setCheckable', bool]
 }
 
 ElementAttr = {
